@@ -4,16 +4,15 @@
 # Copyright (c) 1995-1998 Nick Ing-Simmons. All rights reserved.
 # This program is free software; you can redistribute it and/or
 
+package Tk::Radiobutton; 
 
-use vars qw($VERSION);
-$VERSION = '3.004'; # $Id: //depot/Tk8/Tk/Radiobutton.pm#4$
+use vars qw($VERSION @ISA);
+$VERSION = '3.005'; # $Id: //depot/Tk8/Tk/Radiobutton.pm#5$
 
 # modify it under the same terms as Perl itself, subject 
 # to additional disclaimer in license.terms due to partial
 # derivation from Tk4.0 sources.
 
-package Tk::Radiobutton; 
-use AutoLoader;
 require Tk::Button;
 
 
@@ -23,9 +22,6 @@ Construct Tk::Widget 'Radiobutton';
 sub Tk_cmd { \&Tk::radiobutton }
 
 
-1;
-__END__
-
 sub ClassInit
 {
  my ($class,$mw) = @_;
