@@ -58,10 +58,6 @@ Tcl_DecrRefCount(Tcl_Obj *objPtr)
  SvREFCNT_dec(objPtr);
 }
 
-static SV *ForceScalar(SV *sv);
-
-static SV *ForceScalarLvalue(SV *sv);
-
 static void
 Scalarize(SV *sv, AV *av)
 {
@@ -83,22 +79,13 @@ Scalarize(SV *sv, AV *av)
      for (i=0; i < n; i++)
       {
        if ((svp = av_fetch(av, i, 0)))
-        {  
-         SV *el = *svp;                                       
-         int temp = 0;
-         if (SvROK(el) && SvTYPE(SvRV(el)) == SVt_PVAV)
-          {
-           el = newSVpv("",0);
-           temp = 1;
-           Scalarize(el,(AV *) SvRV(*svp));
-          }
-         Tcl_DStringAppendElement(&ds,LangString(el));
-         if (temp)
-          SvREFCNT_dec(el);
+        {
+         Tcl_DStringAppendElement(&ds,LangString(*svp));
         }
       }
      sv_setpvn(sv,Tcl_DStringValue(&ds), Tcl_DStringLength(&ds));
      Tcl_DStringFree(&ds);
+     fprintf(stderr,__FUNCTION__ " '%s'\n",SvPV(sv,na));
     }
   }
 }
@@ -120,62 +107,39 @@ ForceScalar(SV *sv)
  else
   {
    if (SvROK(sv) && SvTYPE(SvRV(sv)) == SVt_PVAV)
-    {                       
-     /* Callbacks and lists often get stringified by mistake due to 
-        Tcl/Tk's string fixation - don't change the real value
-      */
-     SV *nsv = newSVpv("",0);
-     Scalarize(nsv, (AV *) SvRV(sv));
-     return sv_2mortal(nsv);
+    {
+     Scalarize(sv, (AV *) SvRV(sv));
     }
    else if (!SvOK(sv))
-    {   
-     /* Map undef to null string */
+    {
      sv_setpvn(sv,"",0);
     }
    return sv;
   }
 }
 
-static SV *
-ForceScalarLvalue(SV *sv)
-{
- if (SvTYPE(sv) == SVt_PVAV)
-  {
-   AV *av = (AV *) sv;
-   SV *nsv = newSVpv("",0);
-   av_clear(av);
-   av_store(av,0,nsv);
-   return nsv;
-  }
- else
-  {
-   return sv;
-  }
-}
-
 void
 Tcl_SetBooleanObj (Tcl_Obj *objPtr, int value)
 {
- sv_setiv(ForceScalarLvalue(objPtr),value != 0);
+ sv_setiv(ForceScalar(objPtr),value != 0);
 }
 
 void
 Tcl_SetDoubleObj (Tcl_Obj *objPtr, double value)
 {
- sv_setnv(ForceScalarLvalue(objPtr),value);
+ sv_setnv(ForceScalar(objPtr),value);
 }
 
 void
 Tcl_SetIntObj (Tcl_Obj *objPtr, int value)
 {
- sv_setiv(ForceScalarLvalue(objPtr),value);
+ sv_setiv(ForceScalar(objPtr),value);
 }
 
 void
 Tcl_SetLongObj (Tcl_Obj *objPtr, long value)
 {
- sv_setiv(ForceScalarLvalue(objPtr),value);
+ sv_setiv(ForceScalar(objPtr),value);
 }
 
 void
@@ -183,7 +147,7 @@ Tcl_SetStringObj (Tcl_Obj *objPtr, char *bytes, int length)
 {
  if (length < 0)
   length = strlen(bytes);
- sv_setpvn(ForceScalarLvalue(objPtr), bytes, length);
+ sv_setpvn(ForceScalar(objPtr), bytes, length);
 }
 
 int
@@ -208,7 +172,6 @@ Tcl_GetBooleanFromObj (Tcl_Interp *interp, Tcl_Obj *obj, int *boolPtr)
  static char *no[] =  {"n", "no", "false", "off", NULL};
  if (SvPOK(sv))
   {
-   STRLEN na;
    char *s = SvPV(sv, na);
    char **p = yes;
    while (*p)
@@ -267,30 +230,6 @@ Tcl_NewIntObj (int value)
  return newSViv(value);
 }
 
-Tcl_Obj *
-Tcl_NewBooleanObj (int value)
-{
- return newSViv(value);
-}
-
-Tcl_Obj *
-Tcl_NewObj(void)
-{
- return newSVpvn("",0);
-}
-
-Tcl_Obj *
-Tcl_NewLongObj(long value)
-{
- return newSViv(value);
-}
-
-Tcl_Obj *
-Tcl_NewDoubleObj(double value)
-{
- return newSVnv(value);
-}
-
 Tcl_Obj *
 Tcl_NewStringObj (char *bytes, int length)
 {
@@ -314,8 +253,7 @@ char *
 Tcl_GetStringFromObj (Tcl_Obj *objPtr, int *lengthPtr)
 {
  char *s;
- if ((SvROK(objPtr) && SvTYPE(SvRV(objPtr)) == SVt_PVAV) ||
-      (SvTYPE(objPtr) == SVt_PVAV))
+ if (SvTYPE(objPtr) == SVt_PVAV)
   objPtr = ForceScalar(objPtr);
  if (SvPOK(objPtr))
   {
@@ -329,7 +267,7 @@ Tcl_GetStringFromObj (Tcl_Obj *objPtr, int *lengthPtr)
    s = LangString(objPtr);
    if (lengthPtr)
     *lengthPtr = strlen(s);
-  } 
+  }
  return s;
 }
 
@@ -343,6 +281,12 @@ ForceList(Tcl_Interp *interp, Tcl_Obj *sv)
    int argc= 0;
    LangFreeProc *freeProc = NULL;
    SV **argv;
+   if (SvREADONLY(sv))
+    {
+     STRLEN len;
+     croak("Attempt to treat readonly '%s' as a list",
+            SvPV(sv,len));
+    } 
    if (Lang_SplitString(interp,LangString(sv),&argc,&argv,&freeProc) == TCL_OK)
     {
      int n = argc;
@@ -350,19 +294,11 @@ ForceList(Tcl_Interp *interp, Tcl_Obj *sv)
      while (n-- > 0)
       {
        av_store(av,n,SvREFCNT_inc(argv[n]));
-      }       
+      }
+     sv_setsv(sv,MakeReference((SV *) av));
      if (freeProc)
       (*freeProc)(argc,argv);
-     if (SvREADONLY(sv))
-      {
-       sv_2mortal((SV *) av);
-       return av;
-      }
-     else
-      {
-       sv_setsv(sv,MakeReference((SV *) av));
-       /* DUBIOUS : SvREFCNT_dec((SV *) av); */
-      }
+     SvREFCNT_dec((SV *) av);
     }
    else
     return NULL;
@@ -478,8 +414,10 @@ Tcl_ListObjReplace (Tcl_Interp *interp, Tcl_Obj *listPtr, int first, int count,
 
 Tcl_Obj *
 Tcl_ConcatObj (int objc, Tcl_Obj *CONST objv[])
-{                                              
- return Tcl_NewListObj (objc, objv);
+{
+ LangDebug(__FUNCTION__ " Not Implemented");
+ abort();
+ return NULL;
 }
 
 
@@ -491,11 +429,10 @@ Tcl_DStringAppendElement(dsPtr, string)
 {
     char *s = string;
     int ch;
-    while ((ch = *s))
+    while ((ch = *s++))
      {
       if (isspace(ch))
        break;
-      s++;
      }
     if (Tcl_DStringLength(dsPtr)) {
 	Tcl_DStringAppend(dsPtr, " ", 1);
@@ -514,7 +451,7 @@ void
 Tcl_AppendStringsToObj (Tcl_Obj *obj,...)
 {
  va_list ap;
- char *s; 
+ char *s;
  SV *sv = ForceScalar(obj);
  va_start(ap,obj);
  while ((s = va_arg(ap,char *)))
@@ -522,8 +459,6 @@ Tcl_AppendStringsToObj (Tcl_Obj *obj,...)
    sv_catpv(sv,s);
   }
  va_end(ap);
- if (sv != obj && SvROK(obj))
-  sv_setsv(obj,sv);
 }
 
 /*
@@ -636,8 +571,6 @@ Tcl_AppendToObj(objPtr, bytes, length)
  if (length < 0)
   length = strlen(bytes);
  sv_catpvn(sv, bytes, length);
- if (sv != objPtr && SvROK(objPtr))
-  sv_setsv(objPtr,sv);
 }
 
 void
@@ -673,7 +606,7 @@ Tcl_WrongNumArgs(interp, objc, objv, message)
 }
 
 
-#define DStringSV(svp) ((*svp) ? (*svp = ForceScalar(*svp)) : (*svp = newSVpv("",0), *svp))
+#define DStringSV(svp) ((*svp) ? ForceScalar(*svp) : (*svp = newSVpv("",0), *svp))
 
 #undef Tcl_DStringInit
 void
@@ -739,10 +672,4 @@ Tcl_DStringValue(Tcl_DString *svp)
  return SvPV(sv,len);
 }
 
-void
-Tcl_DStringGetResult(Tcl_Interp *interp, Tcl_DString *svp)
-{
- SV *sv = DStringSV(svp);
- sv_setsv(sv,LangScalarResult(interp));
-}
 
